@@ -14,7 +14,12 @@ Classo and pathlasso are the main functions, they can call every algorithm acord
 
 # can be 'Path-Alg', 'P-PDS' , 'PF-PDS' or 'DR'
 
-def Classo(matrix,lam,typ = 'R1', meth='DR', rho = 1.345, get_lambdamax = False, true_lam=False, e=1., rho_classification=-1., w = None, intercept = False):
+def Classo(matrix,lam,typ = 'R1', meth='DR', rho = 1.345, get_lambdamax = False, true_lam=False, e=None, rho_classification=-1., w = None, intercept = False):
+
+    if e is None:
+        if typ == 'R3':   e = len(matrix[0])/2
+        elif typ == 'R4': e = len(matrix[0])
+
 
     if not w is None : matrices = (  matrix[0]/w, matrix[1],matrix[2] )
     else : matrices = matrix
@@ -79,7 +84,12 @@ def Classo(matrix,lam,typ = 'R1', meth='DR', rho = 1.345, get_lambdamax = False,
     else              : return(beta)
 
 
-def pathlasso(matrix,lambdas=False,n_active=0,lamin=1e-2,typ='LS',meth='Path-Alg',rho = 1.345, true_lam = False, e= 1.,return_sigm= False,rho_classification=-1, w =None, intercept = False):
+def pathlasso(matrix,lambdas=False,n_active=0,lamin=1e-2,typ='R1',meth='Path-Alg',rho = 1.345, true_lam = False, e= None,return_sigm= False,rho_classification=-1, w =None, intercept = False):
+
+    if e is None:
+        if typ == 'R3':   e = len(matrix[0])/2
+        elif typ == 'R4': e = len(matrix[0])
+    
     Nactive = n_active
     if(Nactive==0):Nactive=False
     if (type(lambdas)!= bool):
@@ -101,18 +111,25 @@ def pathlasso(matrix,lambdas=False,n_active=0,lamin=1e-2,typ='LS',meth='Path-Alg
         BETA  = pathlasso_R2(pb,lambdass,n_active=Nactive)
 
     elif(typ=='R3'):
-        pb = problem_R3(matrices,meth,e=e)
+        r = np.sqrt(2*e/n)
+        if not r==1. : matrices_r = (matrices[0]*r;matrices[1],matrices[2]*2)
+        pb = problem_R3(matrices_r,meth)
         lambdamax = pb.lambdamax
         if (true_lam): lambdass=[lamb/lambdamax for lamb in lambdass]
         BETA,S = pathlasso_R3(pb,lambdass,n_active=Nactive)
-        S=np.array(S)/np.sqrt(e)
+        S=np.array(S)/r**2
+        BETA = np.array(BETA)
+
 
     elif(typ=='R4'):
-        meth='DR'
-        pb = problem_R4(matrices,meth,rho,e=e)
+        r = np.sqrt(2*e/n)
+        if not r==1. : matrices_r = (matrices[0]*r;matrices[1],matrices[2]*2)
+        pb = problem_R4(matrices_r,meth,rho/r)
         lambdamax = pb.lambdamax
         if (true_lam): lambdass=[lamb/lambdamax for lamb in lambdass]
         BETA,S = pathlasso_R4(pb,lambdass,n_active=Nactive)
+        S=np.array(S)/r**2
+        BETA = np.array(BETA)
         
     elif(typ == 'C2'):
         lambdamax = h_lambdamax(matrices[0],matrices[2],rho)
@@ -155,4 +172,42 @@ def hub(r,rho) :
         elif(r[j]>0)     : h+= (2*r[j]-rho)*rho
         else             : h+= (-2*r[j]-rho)*rho
     return(h)
+'''
+
+
+'''
+Remark about R3 : 
+
+    The functions Classo_R3 and pathlasso_R3 only allows to compute the solution of R3, with e = n/2 : 
+         min_(beta,sigma) ||Xbeta - y||^2/sigma + n/2 sigma + lambda ||beta||1 = L'(X,y,lambda,beta,sigma) with C.b= 0 and sigma > 0 
+    
+    Now let's say that we have to solve the same problem but with e = r^2 * n/2 :
+        L(r,X,y,lamba,beta,s)   = ||Xbeta - y||^2/s + r^2 *n/2 s + lambda ||beta||1
+                                = ||(Xr)beta - yr||^2/sigma + n/2 sigma + lambda ||beta||1      with sigma = s*r^2
+                                = L'(Xr,yr,lambda,beta,s*r^2)
+        so we just have to solve the problem with e=n/2 , r = sqrt(2e/n), X = X*r , y = y*r and then divide sigma by r^2
+ 
+
+
+
+
+The same remark with R4 holds, but with e = n instead. 
+
+
+
+    The functions Classo_R4 and pathlasso_R4 only allows to compute the solution of R4, with e = n/2 : 
+         min_(beta,sigma) h_rho(Xbeta - y / sigma) sigma + n sigma + lambda ||beta||1 = L'(X,y,rho,lambda,beta,sigma) with C.b= 0 and sigma > 0 
+    
+    Now let's say that we have to solve the same problem but with e = r * n :
+        L(r,X,y,rho,lamba,b,s)  = h_rho((Xbeta - y)/s)  s  + n r^2 s + lambda   ||b||1
+                                = h_p  ( (Xbeta - y)/(sr))  r^2 s  + n r^2 s + lambda ||b||1                    because h_rho(x) =  h_p (x/r) * r^2 , with p = rho/r
+                                = h_p  ( ((Xr)beta - yr)/sigma)  sigma  + n sigma + lambda ||b||1      with sigma = s*r^2 
+                                = L'(Xr,yr,rho/r, lambda,beta,s*r^2)
+
+        so we just have to solve the problem with e=n , r = sqrt(2e/n), X = X*r , y = y*r, rho = rho/r and then divide sigma by r^2
+ 
+
+
+
+
 '''
\ No newline at end of file
