@@ -1,3 +1,4 @@
+N = 10000
 N_frac = 100
 import numpy as np
 import numpy.linalg as LA
@@ -94,7 +95,7 @@ def solve_path_Conc(matrices, stop, n_active=False, lassopath=True,true_lam=Fals
 
     param = parameters_for_update(matrices, lamin, 0, "Conc")
     BETA, LAM = [param.beta], [param.lam]
-    for i in range(N):
+    for i in range(d*N_frac):
 
         up(param)
         BETA.append(param.beta), LAM.append(param.lam)
