@@ -1,5 +1,5 @@
 path = '/Users/lsimpson/Desktop/GitHub/Figures/example1/'
-from CLasso import *
+from classo import *
 
 m,d,d_nonzero,k,sigma =100,100,5,1,0.5
 (X,C,y),sol = random_data(m,d,d_nonzero,k,sigma,zerosum=True,seed= 4)
